'use client'
import React from 'react'
import { Button } from "@heroui/react";
import { Image } from "@heroui/image";
import { Card, CardHeader, CardFooter } from "@heroui/react";
import { FaRegCheckCircle } from "react-icons/fa";
import { CgMoreO } from "react-icons/cg";
import { IoMailOutline } from "react-icons/io5";
import Footer from '@/components/Footer';
import Link from 'next/link';
import ReactBeforeSliderComponent from 'react-before-after-slider-component';
import 'react-before-after-slider-component/dist/build.css';

const page = () => {
    const delimiterIconStyles = {
        width: '20px',
        height: '20px',
        backgroundSize: 'cover',
        borderRadius: 'none',
        backgroundImage: 'url(left-and-right.png)'
    }
    return (
        <>
            <main className='mx-3 xl:mx-20 mt-3 xl:mt-10 mb-10 lg:mb-28'>
                {/* HERO SECTION */}
                <div
                    className="flex flex-col justify-center items-start h-[12rem] p-5 md:p-10 rounded-3xl bg-cover bg-center bg-fixed"
                    style={{
                        backgroundImage: "url('/old-hero.jpg')",
                    }}
                >
                    <p className='text-white text-sm md:text-medium font-medium'><Link className='hover:underline' href={'/'}>HOME</Link> / <Link href={'/project'} className="text-yellow-500 hover:underline">PROJECT</Link></p>
                    <p className="text-white font-semibold text-4xl lg:text-5xl mt-3">Our Projects</p>
                </div>
                {/* HERO SECTION */}

                {/* PROJECTS SECTION */}
                <div className="mt-10 grid grid-cols-1 md:grid-cols-2 gap-4">
                    <Card className='px-5 md:px-10'>
                        <p className="text-center text-lg md:text-2xl my-3 font-semibold uppercase">Outdoor Stone Patio Rebuild</p>
                        <ReactBeforeSliderComponent
                            delimiterIconStyles={delimiterIconStyles}
                            className='border shadow'
                            firstImage={{ imageUrl: '/project/B1.png' }}
                            secondImage={{ imageUrl: '/project/B2.png' }}
                        />
                    </Card>
                    <Card className='px-5 md:px-10'>
                        <p className="text-center text-lg md:text-2xl my-3 font-semibold uppercase">Outdoor Fireplace Build</p>
                        <ReactBeforeSliderComponent
                            delimiterIconStyles={delimiterIconStyles}
                            className='border shadow'
                            firstImage={{ imageUrl: '/project/A1.png' }}
                            secondImage={{ imageUrl: '/project/A2.png' }}
                        />
                    </Card>

                </div>
                {/* PROJECTS SECTION */}

                {/* LETS START SECTION */}
                <div className="mt-6 lg:mt-28 flex flex-col md:flex-row rounded-3xl bg-green-100/30">

                    <div className='w-full md:w-1/2 p-3 md:p-10'>
                        <p className='text-4xl lg:text-5xl font-semibold mt-3 text-slate-800'>Let's build something great <span className="text-yellow-500">together</span></p>
                        <p className='text-lg lg:text-xl mt-8 text-gray-600 leading-8'>Don’t wait any longer to bring your construction dreams to life. Partner with C&CGC and experience unparalleled service and quality.</p>
                        <Button as={Link} href='/contact' className='mt-5 lg:mt-10' variant='shadow' size='md' color='warning'>Contact Us <IoMailOutline /></Button>
                    </div>
                    <div className='w-full md:w-1/2 flex items-end'>
                        <Image
                            isBlurred
                            src='/cta.png'
                            alt='cta'
                            className='w-3/4 mx-auto'
                        />
                    </div>
                </div>
                {/* LETS START SECTION */}
            </main>
            <Footer />
        </>
    )
}

export default page